# load packages
library(sf)
library(readr)
library(ggplot2)
library(rjson)
library(jsonlite)
library(leaflet)
library(RCurl)
library(DT)
library(leaflet)
library(dplyr)

#Load data file 
Data = read.csv("Data.csv", header = TRUE,  sep = ";")
View (Data)
#datatable(head(Trondheim_data))

#subset the data selecting Trondheim and environs with latitude between 63.32 
#and 63.45 and longitude between 10.45 and 10.32.
trondheim_data = Data %>% 
  filter(lengdegrad < 10.45 & lengdegrad > 10.32 & breddegrad <63.45 & breddegrad > 63.32)%>%
  filter(tid > 2020)%>%
  select(hastighet_ned, hastighet_opp, tid, lengdegrad, breddegrad, klient_type, teknologi, ip_as_name, 
                                landkode, enhet)
View (trondheim_data)

######MAPPING######

# you can then pipe this
trondheim_data <- trondheim_data %>%
  flatten(recursive = TRUE) # remove the nested data frame

# Using the datatable function from the DT package to see the first 6 rows of data
datatable(head(trondheim_data))

trondMap <- leaflet(trondheim_data) %>% 
  addTiles( attribution='2908 entries for TRONDHEIM, NORWAY. Map tiles by Kwame') %>% 
  addCircles(~lengdegrad, ~breddegrad)

trondMap

######Statistics########
#4G ONLY
trondheim_4G = trondheim_data %>% 
  filter(lengdegrad < 10.45 & lengdegrad > 10.32 & breddegrad <63.45 & breddegrad > 63.32)%>%
  filter(tid > 2020)%>%
  filter(teknologi == '4G')%>%
  select(hastighet_ned, hastighet_opp, tid, lengdegrad, breddegrad, klient_type, teknologi, ip_as_name, 
         landkode, enhet)
View (trondheim_4G)

mean_4G <- 
  trondheim_4G %>% summarise_if(is.numeric, mean)
mean_4G

standard_4G <- 
  trondheim_4G %>% summarise_if(is.numeric, sd)
standard_4G

variance_4G <- 
  trondheim_4G %>% summarise_if(is.numeric, var)
variance_4G

#WLAN ONLY
trondheim_wlan = trondheim_data %>% 
  filter(lengdegrad < 10.45 & lengdegrad > 10.32 & breddegrad <63.45 & breddegrad > 63.32)%>%
  filter(tid > 2020)%>%
  filter(teknologi == 'WLAN')%>%
  select(hastighet_ned, hastighet_opp, tid, lengdegrad, breddegrad, klient_type, teknologi, ip_as_name, 
         landkode, enhet)
View (trondheim_wlan)

mean_wlan <- 
  trondheim_wlan %>% summarise_if(is.numeric, mean)
mean_wlan

standard_wlan <- 
  trondheim_wlan %>% summarise_if(is.numeric, sd)
standard_wlan

variance_wlan <- 
  trondheim_wlan %>% summarise_if(is.numeric, var)
variance_wlan



