# load packages
library(sf)
library(readr)
library(ggplot2)
library(rjson)
library(jsonlite)
library(leaflet)
library(RCurl)
library(DT)
library(leaflet)
library(dplyr)
library(lubridate)

#Load data file 
setwd("~/3rd Semester/Specialization Project/Data")
Data = read.csv("Data.csv", header = TRUE,  sep = ";")
View (Data)
#datatable(head(Trondheim_data))

#subset the data selecting Trondheim and environs with latitude between 63.32 
#and 63.45 and longitude between 10.45 and 10.32.
trondinCorona = Data %>% 
  filter(lengdegrad < 10.45 & lengdegrad > 10.32 & breddegrad <63.45 & breddegrad > 63.32)%>%
  filter(tid >= as.Date("2020-03-12"))%>%
  select(hastighet_ned, hastighet_opp, tid, lengdegrad, breddegrad, klient_type, teknologi, ip_as_name, 
         landkode, enhet)
View (trondinCorona)

######MAPPING######

# you can then pipe this
trondinCorona <- trondinCorona %>%
  flatten(recursive = TRUE) # remove the nested data frame

# Using the datatable function from the DT package to see the first 6 rows of data
datatable(head(trondinCorona))

trondMap <- leaflet(trondinCorona) %>% 
  addTiles( attribution='2,080 entries for TRONDHEIM, NORWAY after March 12th. Map tiles by Kwame') %>% 
  addCircles(~lengdegrad, ~breddegrad)
trondMap

######Statistics########
#4G ONLY
trondinCorona_4G = trondinCorona %>% 
  filter(lengdegrad < 10.45 & lengdegrad > 10.32 & breddegrad <63.45 & breddegrad > 63.32)%>%
  filter(tid >= as.Date("2020-03-12"))%>%
  filter(teknologi == '4G')%>%
  select(hastighet_ned, hastighet_opp, tid, lengdegrad, breddegrad, klient_type, teknologi, ip_as_name, 
         landkode, enhet)
View (trondinCorona_4G)

mean_4G <- 
  trondinCorona_4G %>% summarise_if(is.numeric, mean)
mean_4G

standard_4G <- 
  trondinCorona_4G %>% summarise_if(is.numeric, sd)
standard_4G

variance_4G <- 
  trondinCorona_4G %>% summarise_if(is.numeric, var)
variance_4G

#WLAN ONLY
trondinCorona_wlan = trondinCorona %>% 
  filter(lengdegrad < 10.45 & lengdegrad > 10.32 & breddegrad <63.45 & breddegrad > 63.32)%>%
  filter(tid >= as.Date("2020-03-12"))%>%
  filter(teknologi == 'WLAN')%>%
  select(hastighet_ned, hastighet_opp, tid, lengdegrad, breddegrad, klient_type, teknologi, ip_as_name, 
         landkode, enhet)
View (trondinCorona_wlan)

mean_wlan <- 
  trondinCorona_wlan %>% summarise_if(is.numeric, mean)
mean_wlan

standard_wlan <- 
  trondinCorona_wlan %>% summarise_if(is.numeric, sd)
standard_wlan

variance_wlan <- 
  trondinCorona_wlan %>% summarise_if(is.numeric, var)
variance_wlan

