############## PLOTTING ALL YEAR ####################

############### PLOTTING BY AVERAGE MONTHLY DOWNLOAD SPEED ####################
download_by_month = table(year2018$Month_abbr)

neworder = c('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec')
# # setcolorder(sales_by_month_freq, neworder)

month_data = data.frame(download_by_month)
names(month_data)[1]<-'Month'

bar_graph1 = ggplot(month_data, aes(x=factor(Month, level = neworder), y=Freq), 
                    colour = Month)+
  geom_bar(stat='identity', col = "brown", fill = "brown4") +
  geom_text(aes(label = Freq), vjust = -0.5, size = 3)

# add y-label and add Title
bar_graph1 + labs(x = 'Month', y = 'Frequency',
                  title = "Monthly Test of Internet Speed Using NETTFART (2018)",
                  subtitle = "Frequency by Month",
                  caption = "Graph by Kwame") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))


#Alternatively
grouped_month = trondheim %>% group_by(Month_abbr, Download)

extra = data.frame(Month_abbr=grouped_month$Month_abbr,Download = grouped_month$Download)

mean_by_month = aggregate(Download ~ Month_abbr, extra, mean)

neworder = c('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec')

month_data<-data.frame(mean_by_month)
names(month_data)[1]<-'Month'

line_graph1 = month_data %>%
  ggplot(aes(x=factor(Month, level = neworder), y=Download)) +
  geom_point(size = 3, alpha = 0.5, col = "burlywood1") +
  geom_line(col = "burlywood", group = 1)  

line_graph1 +
  #facet_wrap(~) +
  labs(title = "Internet Performance by Months from NETTFART (Tronheim, 2018)", 
       subtitle = "Average Monthly Download Speed results by Month",
       x = "Months", 
       y = "Average Download speed (Mbs)", 
       caption = "Graph by Kwame") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))


############### PLOTTING BY AVERAGE DAILY DOWNLOAD SPEED ####################
download_by_day_of_month = table(year$Day)

day_freq = data.frame(download_by_day_of_month)

names(day_freq)[1] = 'Day_of_Month'

bar_graph2 = ggplot(data=day_freq, aes(x=Day_of_Month, y=Freq)) +
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "brown", fill = "brown4")+
  theme(text = element_text(size = 15.3)) 

bar_graph2 + labs(x = 'Day of Month', y = 'Frequency', fill = NULL,
                  title = "Daily Test of Internet Using NETTFART (Randaberg, 2018)",
                  subtitle = "Frequency by Day of Month",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9),
        axis.text.x = element_text(angle = 45))

#Alternatively
grouped_day = trondheim %>% group_by(Day, Download)

extra_day = data.frame(Day=grouped_day$Day,Download = grouped_day$Download)

mean_by_day = aggregate(Download ~ Day, extra_day, mean)

day_freq = data.frame(mean_by_day)

names(day_freq)[1] = 'Day_of_Month'

bar_graph3 = day_freq %>% 
  ggplot(aes(x=Day_of_Month, y=Download)) +
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "burlywood", fill = "burlywood1")

bar_graph3 + labs(x = 'Day of Month', y = 'Average Download Speed (Mbs)',
                  title = "Daily Internet Performance from NETTFART (Trondheim, 2018)",
                  subtitle = "Average Download Speed by Day of Month",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9),
        axis.text.x = element_text(angle = 45))+
  scale_x_continuous(breaks = seq(1, 31, 1))


############### PLOTTING BY HOURLY DOWNLOAD SPEED ####################
download_by_hour_freq = table(randaberg$Hour)

hour_freq = data.frame(download_by_hour_freq)

names(hour_freq)[1] = 'Hour'

bar_graph4 = ggplot(data=hour_freq, aes(x=Hour, y=Freq)) +
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "brown", fill = "brown4")

bar_graph4 + labs(x = 'Hour', y = 'Frequency',
                  title = "Hourly Speed Test of Internet Using NETTFART (Randaberg, 2018)",
                  subtitle = "Frequency by Hour (24-Hour)",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5),
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9),
        axis.text.x = element_text(angle = 45))

#ALTERNATIVELY
grouped_hour = oslo %>% group_by(Hour, Download)

extra_hour = data.frame(Hour=grouped_hour$Hour,Download = grouped_hour$Download)

mean_by_hour = aggregate(Download ~ Hour, extra_hour, mean)

hour_freq = data.frame(mean_by_hour)

names(hour_freq)[1] = 'Hour'

bar_graph5 = ggplot(data=hour_freq, aes(x=Hour, y=Download))+
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "burlywood", fill = "burlywood1")

bar_graph5 + labs(x = 'Hour', y = 'Avearge Download speed (Mbs) ',
                  title = "Daily Internet Performance from NETTFART (Oslo, 2018)",
                  subtitle = "Hourly Average Download Speed",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9),
        axis.text.x = element_text(angle = 45))+
  scale_x_continuous(breaks = seq(00, 23, 1)) 


############### PLOTTING BY WEEKLY DOWNLOAD SPEED ####################
troms$day_of_week = format(troms$Date, format = "%A")

week_days = table(troms$day_of_week)

day_freq = data.frame(week_days)

names(day_freq)[1] = 'Day'
# day_freq

# Need to Use so Columns of Graph are correctly ordered: look at aes(x=)
days_ordered = c('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday')

bar_graph6 = ggplot(data=day_freq, aes(x=factor(Day, level = days_ordered), y=Freq), fill = Day)+
  geom_bar(stat ='identity',width=0.7,position=position_dodge(width=.8), 
           col = "brown", fill = "brown4") + 
  geom_text(aes(label = Freq), vjust = -0.5)

bar_graph6 + labs(x = 'Day of Week', y = 'Frequency',
                  title = "Weekly Speed Test of Internet Using NETTFART (Troms & Finnmark, 2018)",
                  subtitle = "Weekly Frequency",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5),
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))

#ALTERNATIVELY
trondheim$day_of_week = format(trondheim$Date, format = "%A")

grouped_week = trondheim %>% group_by(day_of_week, Download)

extra_week = data.frame(day_of_week=grouped_week$day_of_week,
                        Download = grouped_week$Download)

mean_by_week = aggregate(Download ~ day_of_week, extra_week, mean)

week_freq = data.frame(mean_by_week)

names(week_freq)[1] = 'Day'
# week_freq

# Need to Use so Columns of Graph are correctly ordered: look at aes(x=)
days_ordered = c('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday')

bar_graph7 = ggplot(data=week_freq, aes(x=factor(Day, level = days_ordered), y=Download))+
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "burlywood", fill = "burlywood1")  + 
  geom_text(aes(label = round(Download)), vjust = -0.5)

bar_graph7 + labs(x = 'Day of Week', y = 'Avearge Download Speed (Mbs)',
                  title = "Weekly Internet Performance from NETTFART (Trondheim, 2018)",
                  subtitle = "Weekly Average Download Speed",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))