############## PLOTTING ALL YEAR ####################

############ PLOTTING BY COUNTY'S AVERAGE LATENCY ################
#COUNTIES COUNT
counties = year2020 %>%
  filter(Country == 'NO')%>%
  count(County) 
view(counties)

grouped = year2020 %>% group_by(County, Ping)

extr_cols = data.frame(County=grouped$County,Ping = grouped$Ping)

mean_by_county = aggregate(Ping ~ County, extr_cols, mean)

ordered_freq = mean_by_county %>% arrange(desc(mean_by_county$Ping))

head(ordered_freq)

bar_graph = ggplot(data=ordered_freq, aes(x=reorder(County,Ping), y=Ping),
                   fill = County)+
  geom_bar(stat='identity', col = "burlywood", fill = "lightgreen", 
           width=0.7,position=position_dodge(width=.8)) + coord_flip() +
  geom_text(aes(label = round(Ping)), hjust = -0.3, size = 3)

bar_graph + labs(x = 'County', y = 'Average Ping Speed (Mbs)',
                 title = "Internet Performance based on County (2018)",
                 subtitle = "Average Latency by County from NETTFART",
                 caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))


############### PLOTTING BY AVERAGE MONTHLY Ping SPEED ####################
Ping_by_month = table(year2020$Month_abbr)

neworder = c('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec')
# # setcolorder(sales_by_month_freq, neworder)

month_data = data.frame(Ping_by_month)
names(month_data)[1]<-'Month'

bar_graph1 = ggplot(month_data, aes(x=factor(Month, level = neworder), y=Freq), 
                    colour = Month)+
  geom_bar(stat='identity', col = "brown", fill = "brown4") +
  geom_text(aes(label = Freq), vjust = -0.5, size = 3)

# add y-label and add Title
bar_graph1 + labs(x = 'Month', y = 'Frequency',
                  title = "Monthly Test of Internet Speed Using NETTFART (2018)",
                  subtitle = "Frequency by Month",
                  caption = "Graph by Kwame,2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))


#Alternatively
grouped_month = year2020 %>% group_by(Month_abbr, Ping)

extra = data.frame(Month_abbr=grouped_month$Month_abbr,Ping = grouped_month$Ping)

mean_by_month = aggregate(Ping ~ Month_abbr, extra, mean)

neworder = c('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec')

month_data<-data.frame(mean_by_month)
names(month_data)[1]<-'Month'

line_graph1 = month_data %>%
  ggplot(aes(x=factor(Month, level = neworder), y=Ping)) +
  geom_point(size = 3, alpha = 0.5, col = "burlywood1") +
  geom_line(col = "burlywood", group = 1)  

line_graph1 +
  #facet_wrap(~) +
  labs(title = "Internet Performance by Months from NETTFART (2018)", 
       subtitle = "Average Monthly Ping Speed results by Month",
       x = "Months", 
       y = "Average Ping speed (Mbs)", 
       caption = "Graph by Kwame") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))


############### PLOTTING BY AVERAGE DAILY Ping SPEED ####################
Ping_by_day_of_month = table(year2018$Day)

day_freq = data.frame(Ping_by_day_of_month)

names(day_freq)[1] = 'Day_of_Month'

bar_graph2 = ggplot(data=day_freq, aes(x=Day_of_Month, y=Freq)) +
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "brown", fill = "brown4")+
  theme(text = element_text(size = 15.3)) 

bar_graph2 + labs(x = 'Day of Month', y = 'Frequency', fill = NULL,
                  title = "Daily Test of Internet Using NETTFART (Randaberg, 2018)",
                  subtitle = "Frequency by Day of Month",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9),
        axis.text.x = element_text(angle = 45))

#Alternatively
grouped_day = trondheim %>% group_by(Day, Ping)

extra_day = data.frame(Day=grouped_day$Day,Ping = grouped_day$Ping)

mean_by_day = aggregate(Ping ~ Day, extra_day, mean)

day_freq = data.frame(mean_by_day)

names(day_freq)[1] = 'Day_of_Month'

bar_graph3 = day_freq %>% 
  ggplot(aes(x=Day_of_Month, y=Ping)) +
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "burlywood", fill = "burlywood1")

bar_graph3 + labs(x = 'Day of Month', y = 'Average Ping Speed (Mbs)',
                  title = "Daily Internet Performance from NETTFART (Trondheim, 2018)",
                  subtitle = "Average Ping Speed by Day of Month",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9),
        axis.text.x = element_text(angle = 45))+
  scale_x_continuous(breaks = seq(1, 31, 1))


############### PLOTTING BY HOURLY Ping SPEED ####################
Ping_by_hour_freq = table(year2020$Hour)

hour_freq = data.frame(Ping_by_hour_freq)

names(hour_freq)[1] = 'Hour'

bar_graph4 = ggplot(data=hour_freq, aes(x=Hour, y=Freq)) +
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "brown", fill = "brown4")

bar_graph4 + labs(x = 'Hour', y = 'Frequency',
                  title = "Hourly Speed Test of Internet Using NETTFART (Randaberg, 2018)",
                  subtitle = "Frequency by Hour (24-Hour)",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5),
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9),
        axis.text.x = element_text(angle = 45))

#ALTERNATIVELY
grouped_hour = year2020 %>% group_by(Hour, Ping)

extra_hour = data.frame(Hour=grouped_hour$Hour,Ping = grouped_hour$Ping)

mean_by_hour = aggregate(Ping ~ Hour, extra_hour, mean)

hour_freq = data.frame(mean_by_hour)

names(hour_freq)[1] = 'Hour'

bar_graph5 = ggplot(data=hour_freq, aes(x=Hour, y=Ping))+
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "burlywood", fill = "burlywood1")

bar_graph5 + labs(x = 'Hour', y = 'Avearge Ping speed (Mbs) ',
                  title = "Daily Internet Performance from NETTFART (Oslo, 2018)",
                  subtitle = "Hourly Average Ping Speed",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9),
        axis.text.x = element_text(angle = 45))+
  scale_x_continuous(breaks = seq(00, 23, 1)) 


############### PLOTTING BY WEEKLY Ping SPEED ####################
aprweek4$day_of_week = format(aprweek4$Date, format = "%A")

week_days = table(aprweek4$day_of_week)

day_freq = data.frame(week_days)

names(day_freq)[1] = 'Day'
# day_freq

# Need to Use so Columns of Graph are correctly ordered: look at aes(x=)
days_ordered = c('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday')

bar_graph6 = ggplot(data=day_freq, aes(x=factor(Day, level = days_ordered), y=Freq), fill = Day)+
  geom_bar(stat ='identity',width=0.7,position=position_dodge(width=.8), 
           col = "brown", fill = "brown4") + 
  geom_text(aes(label = Freq), vjust = -0.5)

bar_graph6 + labs(x = 'Day of Week', y = 'Frequency',
                  title = "Weekly Speed Test of Internet Using NETTFART (2018)",
                  subtitle = "Weekly Frequency",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5),
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))

#ALTERNATIVELY
aprweek4$day_of_week = format(aprweek4$Date, format = "%A")

grouped_week = aprweek4 %>% group_by(day_of_week, Ping)

extra_week = data.frame(day_of_week=grouped_week$day_of_week,
                        Ping = grouped_week$Ping)

mean_by_week = aggregate(Ping ~ day_of_week, extra_week, mean)

week_freq = data.frame(mean_by_week)

names(week_freq)[1] = 'Day'
# week_freq

# Need to Use so Columns of Graph are correctly ordered: look at aes(x=)
days_ordered = c('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday')

bar_graph7 = ggplot(data=week_freq, aes(x=factor(Day, level = days_ordered), y=Ping))+
  geom_bar(stat='identity',width=0.7,position=position_dodge(width=.8),
           col = "burlywood", fill = "burlywood1")  + 
  geom_text(aes(label = round(Ping)), vjust = -0.5)

bar_graph7 + labs(x = 'Day of Week', y = 'Avearge Ping Speed (Mbs)',
                  title = "Weekly Internet Performance from NETTFART (2018)",
                  subtitle = "Weekly Average Latency",
                  caption = "Graph by Kwame, 2021") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))


########### FEB 2020 ###########
feb2020 = year2020 %>% 
  filter(Month_abbr == 'Feb')


####### 1st WEEK ###########
febweek1 = feb2020 %>% 
  filter(between(Day, 3,9))

febweek2 = feb2020 %>% 
  filter(between(Day, 10,16))

febweek3 = feb2020 %>% 
  filter(between(Day, 17,23))

febweek4 = feb2020 %>% 
  filter(between(Day, 24,29))


########### MARCH 2020 ###########
mar2020 = year2020 %>% 
  filter(Month_abbr == 'Mar')


####### 1st WEEK ###########
febweek5 = mar2020 %>% 
  filter(Day == '1')  

marweek1 = mar2020 %>% 
  filter(between(Day, 2,8))

marweek2 = mar2020 %>% 
  filter(between(Day, 9,15))

marweek3 = mar2020 %>% 
  filter(between(Day, 16,22))

marweek4 = mar2020 %>% 
  filter(between(Day, 23,29))

marweek5 = mar2020 %>% 
  filter(between(Day, 30,31))

########### APR 2020 ###########
apr2020 = year2020 %>% 
  filter(Month_abbr == 'Apr')


####### 1st WEEK ###########
aprweek1 = apr2020 %>% 
  filter(between(Day, 1,5))

aprweek2 = apr2020 %>% 
  filter(between(Day, 6,12))

aprweek3 = apr2020 %>% 
  filter(between(Day, 13,19))

aprweek4 = apr2020 %>% 
  filter(between(Day, 20,26))



























