# load packages
library(sf)
library(readr)
library(ggplot2)
library(rjson)
library(jsonlite)
library(leaflet)
library(RCurl)
library(DT)
library(dplyr)
library(RColorBrewer)
library(rgdal)
library(rgeos)
library(raster)
library(OpenStreetMap)
library(lubridate)
library(sp)

#Load data file
setwd("~/4th Semester/Thesis/Data")
Data = read.csv("Data.csv", header = TRUE,  sep = ";")
View (Data)
head(Data)

#Excluding Cellular Data with download speed greater than 100Mb/s & roaming
qq = Data[-which(Data$hastighet_ned >=100 & Data$teknologi == '4G'),]
qq1 = qq[-which(Data$hastighet_ned >=100 & Data$teknologi == '3G'),]
qq2 = qq1[-which(Data$hastighet_ned >=100 & Data$teknologi == '2G'),]
qq3 = qq2[-which(Data$network_is_roaming == 'true'),]
View(qq3)

#Norway only
norway_data = qq3 %>% 
  filter(land_geoip == 'NO') %>% 
  filter(between(lengdegrad,4.7131, 31.1106)) %>% 
  filter(between(breddegrad,58.0333, 71.0373))
View (norway_data)

device = filter(qq3, enhet == 'iPad' & teknologi == 'WLAN')
View (device)

#Outside Norway only
outNorway_data = qq2 %>% 
  filter(!land_geoip == 'NO', !teknologi == 'WLAN') %>%
  filter(!landkode == 'NO')
View (outNorway_data)


################ PEAK TIME/ RUSH HOUR ####################
peakTime = norway_data %>% 
  filter((hour(tid) == 18 & minute(tid) == 59) | 
           (hour(tid) == 21 & minute(tid) <= 1))
View(peakTime)


############### Roaming ########################
roaming = Data %>% 
  filter(network_is_roaming == 'true', !teknologi == 'WLAN', !land_geoip == 'NO')
View(roaming)


################ Operators & Providers #################
operators = norway_data %>%
  count(ip_as_name)
View (operators)

providerTarget = c('29695','15659')
provider = filter(Data, public_ip_asn %in% providerTarget)
View(provider)

#PIE CHART
indices = operators[,2]>=5000
pie(operators[,2][indices],labels = row.names(operators)[indices], 
    main = "Operators pie chart", 
    col = brewer.pal(length(operators[,2][indices]),'Spectral'))
legend('topleft', legend = row.names(operators)[indices], 
       fill = brewer.pal(length(operators[,2][indices]),'Spectral'))

sim_operator = norway_data %>% 
  count(sim_operator_name)
View(sim_operator)


############### Before Lockdown ###########
b4Lock = filter(norway_data, tid >= as.Date("2019-10-12"), 
                tid <= as.Date("2020-03-12"))
View(b4Lock)

#Before Lockdown Operators
b4Operators = b4Lock %>%
  count(ip_as_name)
View (b4Operators)

#PIE CHART
indices = b4Operators[,2]>=5000
pie(b4Operators[,2][indices],labels = row.names(b4Operators)[indices], 
    main = "Before Lockdown Operators pie chart", 
    col = brewer.pal(length(b4Operators[,2][indices]),'Spectral'))
legend('topleft', legend = row.names(b4Operators)[indices], 
       fill = brewer.pal(length(b4Operators[,2][indices]),'Spectral'))

############### During Lockdown ###########
duringLock = filter(norway_data, tid >= as.Date("2020-03-12"))
View(duringLock)

#During Lockdown Operators
duringOperators = duringLock %>%
  count(ip_as_name)
View (duringOperators)

#PIE CHART
indices = duringOperators[,2]>=5000
pie(duringOperators[,2][indices],labels = row.names(duringOperators)[indices], 
    main = "During Lockdown Operators pie chart", 
    col = brewer.pal(length(duringOperators[,2][indices]),'Spectral'))
legend('topleft', legend = row.names(duringOperators)[indices], 
       fill = brewer.pal(length(duringOperators[,2][indices]),'Spectral'))

#WLAN
wlanOnly = #norway_data %>% 
  filter(norway_data, !teknologi %in% c('4G','3G', '2G'))
class(wlanOnly)

############## MAPPING #################

# you can then pipe this
data <- trondheim_data %>%
  flatten(recursive = TRUE) # remove the nested data frame

# Using the datatable function from the DT package to see the first 6 rows of data
datatable(head(data))

NorgeMap <- leaflet(data) %>% 
  addTiles( attribution='Map tiles by Kwame') %>% 
  addCircles(~lengdegrad, ~breddegrad)
NorgeMap


######Statistics########
trondb4Corona_4G = trondb4Corona %>% 
  filter(lengdegrad < 10.45 & lengdegrad > 10.32 & 
           breddegrad <63.45 & breddegrad > 63.32)%>%
  filter(tid <= as.Date("2020-03-12"))%>%
  filter(teknologi == '4G')%>%
  select(hastighet_ned, hastighet_opp, tid, lengdegrad, breddegrad, 
         klient_type, teknologi, ip_as_name, landkode, enhet)
View (trondb4Corona_4G)

mean_b4 <- 
  b4Lock %>% summarise_if(is.numeric, mean)
mean_b4

standard_b4 <- 
  b4Lock %>% summarise_if(is.numeric, sd)
standard_b4

variance_b4 <- 
  b4Lock %>% summarise_if(is.numeric, var)
variance_b4
