library(tidyverse)
library(kableExtra)
library(gridExtra)

#Load 2020
setwd("~/4th Semester/Thesis/Data/NETT FART")
year20 = read.csv("nettfart-2020.csv", header = TRUE,  sep = ";",quote = "\"")
year2020 = separate(year20, col = Time, into = c("Date", "Time"), sep = " ")%>%
  mutate(Date = as.Date(Date), Download = Download/1000, upload = upload/1000 ) %>%
  dplyr::select(Download, upload, Ping, Date, Time, ISP, City, County, Country, 
                Platform) %>%
  filter(Country == 'NO')

#Load 2019
setwd("~/4th Semester/Thesis/Data/NETT FART")
year19 = read.csv("nettfart-2019.csv", header = TRUE,  sep = ";",quote = "\"")
year2019 = separate(year19, col = Time, into = c("Date", "Time"), sep = " ")%>%
  mutate(Date = as.Date(Date), Download = Download/1000, upload = upload/1000) %>%
  dplyr::select(Download, upload, Ping, Date, Time, ISP, City, County, Country, 
                Platform) %>%
  filter(Country == 'NO')

#Load 2018
setwd("~/4th Semester/Thesis/Data/NETT FART")
year18 = read.csv("nettfart-2018.csv", header = TRUE,  sep = ";",quote = "\"")
year2018 = separate(year18, col = Time, into = c("Date", "Time"), sep = " ")%>%
  mutate(Date = as.Date(Date), Download = Download/1000, upload = upload/1000) %>%
  dplyr::select(Download, upload, Ping, Date, Time, ISP, City, County, Country, 
                Platform) %>%
  filter(Country == 'NO')


#View Data 
df = head(year2020)
kable(df) %>% 
  kable_styling(bootstrap_options = "striped", font_size = 10, full_width = F)

summary(year2020)


#Creating new columns Year, Month and YeMo (Year + Month)
#Extract Year using Lubridate
year2020$Year = lubridate::year(year2020$Date)
year2019$Year = lubridate::year(year2019$Date)
year2018$Year = lubridate::year(year2018$Date)
#Extract month
year2020$Month = lubridate::month(year2020$Date)
year2019$Month = lubridate::month(year2019$Date)
year2018$Month = lubridate::month(year2018$Date)
#Extract Day
year2020$Day = lubridate::day(year2020$Date)
year2019$Day = lubridate::day(year2019$Date)
year2018$Day = lubridate::day(year2018$Date)
#Extract Hour
year2020$Hour = lubridate::hour(year2020$Date)
year2019$Hour = lubridate::hour(year2019$Date)
year2018$Hour = lubridate::hour(year2018$Date)
#Join Year and month to aid monthly aggregate
year2020$YeMo = paste(year2020$Year, year2020$Month)
year2019$YeMo = paste(year2019$Year, year2019$Month)
year2018$YeMo = paste(year2018$Year, year2018$Month)

#Aggregate by the mean for average daily speed
aggyear2020 = aggregate(year2020, by = list(year2020$YeMo), FUN = mean, 
                      na.rm = FALSE)
aggyear2019 = aggregate(year2019, by = list(year2019$YeMo), FUN = mean, 
                        na.rm = FALSE)
aggyear2018 = aggregate(year2018, by = list(year2018$YeMo), FUN = mean, 
                        na.rm = FALSE)

aggyear2020$Month_abbr = month.abb[as.numeric((aggyear2020$Month))]
aggyear2019$Month_abbr = month.abb[as.numeric((aggyear2019$Month))]
aggyear2018$Month_abbr = month.abb[as.numeric((aggyear2018$Month))]

#neworder<-c('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec')

#Plotting graph for years in the same graph for comparison 
#(Download against month)
LG1 = ggplot() + geom_line(aes(y = Download, x = Month_abbr), size = 0.8,
                           colour = "blue", data = aggyear2020) + 
  geom_line(aes(y = Download, x = Month_abbr), size = 0.8,
            colour = "red", data = aggyear2019) +
  geom_line(aes(y = Download, x = Month_abbr), size = 0.8,
            colour = "green", data = aggyear2018) 
  #+  geom_line(aes(y = Download, x = Month), size = 0.8,
  #        colour = "black", data = aggyear2017)

LG1 + labs(title = "Monthly Download Speed", subtitle = "Average Daily Download 
           Speed results by Month from NETTFART (Blue - 2020, Red - 2019, 
           Green - 2018)" ,
           x = "Months", y = "Average Download speed (Mbs)", 
           caption = "Graph by Kwame") + 
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9)) #+
#  scale_x_continuous(breaks = seq(1, 12, 1))


#(upload against month)
LG2 = ggplot() + geom_line(aes(y = upload, x = Month_abb), size = 0.8,
                           colour = "blue", data = aggyear2020) + 
  geom_line(aes(y = upload, x = Month_abb), size = 0.8,
            colour = "red", data = aggyear2019) +
  geom_line(aes(y = upload, x = Month_abb), size = 0.8,
            colour = "green", data = aggyear2018) 
#+  geom_line(aes(y = Download, x = Month), size = 0.8,
#        colour = "black", data = aggyear2017)

LG2 + labs(title = "Monthly Upload Speed", subtitle = "Average Daily upload 
           Speed results by Month from NETTFART (Blue - 2020, Red - 2019, 
           Green - 2018)" ,
           x = "Months", y = "Average Upload speed (Mbs)", 
           caption = "Graph by Kwame") + 
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9)) +
  scale_x_continuous(breaks = seq(1, 12, 1))

grid.arrange(LG1, LG2, ncol = 2, nrow = 2)

LG2 = aggyear2020 %>%
  ggplot(aes(Month_abbr, Download, colour = Year, group = 1)) +
  geom_point(size = 3, alpha = 0.5) +
  geom_line(col = "blue") 

LG3 = aggyear2019 %>% 
  ggplot(aes(Month, Download, colour = Year)) +
  geom_point() +
  geom_line()

LG4 = aggyear2018 %>% 
  ggplot(aes(Month, Download, colour = Year)) +
  geom_point() +
  geom_line()


LG2 +
  #facet_wrap(~) +
  labs(title = "Monthly Download Speed", 
       subtitle = "Average Daily Download Speed results by Month from NETTFART",
       x = "Months", 
       y = "Average Download speed (Mbs)", 
       caption = "Graph by Kwame") +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9)) #+
#  scale_x_continuous(breaks = seq(1, 12, 1))


