# load packages
library(tidyverse)
library(kableExtra)

#Load data file 
setwd("~/4th Semester/Thesis/Data")
data = read.csv("Data.csv", header = TRUE,  sep = ";")
data$tid1 = data$tid
Data = separate(data, col = tid1, into = c("Date", "time"), sep = " ") %>%
  mutate(Date = as.Date(Date)) %>% 
  dplyr::select(hastighet_ned, hastighet_opp, tid, Date, time, lengdegrad, 
                breddegrad,teknologi, ip_as_name, landkode, ping_median, 
                network_is_roaming)

#Excluding Cellular Data with download speed greater than 100Mb/s & roaming
qq = Data[-which(Data$hastighet_ned >=100 & Data$teknologi == '4G'),]
qq1 = qq[-which(Data$hastighet_ned >=100 & Data$teknologi == '3G'),]
qq2 = qq1[-which(Data$hastighet_ned >=100 & Data$teknologi == '2G'),]
myData = qq2[-which(Data$network_is_roaming == 'true'),]


#View Data 
df = head(myData)
kable(df) %>% 
  kable_styling(bootstrap_options = "striped", font_size = 10, full_width = F)

summary(myData)


#Creating new columns Year, Month and YeMo (Year + Month)
#Extract Year using Lubridate
myData$Year = lubridate::year(myData$tid)
#Extract month
myData$Month = lubridate::month(myData$tid)
#Join Year and month to aid monthly aggregate
myData$YeMo = paste(myData$Year, myData$Month)

#Aggregate by the mean for average daily speed
aggmyData = aggregate(myData, by = list(myData$YeMo), FUN = mean, 
                      na.rm = FALSE)
#filter years 
aggmyData_2017 = filter(aggmyData, Year == "2017")
aggmyData_2018 = filter(aggmyData, Year == "2018")
aggmyData_2019 = filter(aggmyData, Year == "2019")
aggmyData_2020 = filter(aggmyData, Year == "2020")


#Plotting graph for years in the same graph for comparison 
#(Download against month)
LG1 = ggplot() + geom_line(aes(y = hastighet_ned, x = Month), size = 0.8,
                           colour = "blue", data = aggmyData_2019) + 
  geom_line(aes(y = hastighet_ned, x = Month), size = 0.8,
            colour = "red", data = aggmyData_2020) +
  geom_line(aes(y = hastighet_ned, x = Month), size = 0.8,
            colour = "green", data = aggmyData_2018) +
  geom_line(aes(y = hastighet_ned, x = Month), size = 0.8,
            colour = "black", data = aggmyData_2017)

LG1 + labs(title = "Monthly Download Speed", subtitle = "Average Daily Download 
           Speed results by Month from NETTFART (Red = 2020, Blue = 2019, 
           Green = 2018, Black = 2017)" ,
           x = "Months", y = "Average Download speed (Mbs)", 
           caption = "Graph by Kwame") + 
  theme(plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))+
  scale_x_continuous(breaks = seq(1, 12, 1))

#(Upload against month)
LG1 = ggplot() + geom_line(aes(y = hastighet_opp, x = Month), size = 0.8,
                           colour = "blue", data = aggmyData_2019) + 
  geom_line(aes(y = hastighet_opp, x = Month), size = 0.8,
            colour = "red", data = aggmyData_2020) +
  geom_line(aes(y = hastighet_opp, x = Month), size = 0.8,
            colour = "green", data = aggmyData_2018) +
  geom_line(aes(y = hastighet_opp, x = Month), size = 0.8,
            colour = "black", data = aggmyData_2017)

LG1 + labs(title = "Monthly Upload Speed", subtitle = "Average Daily Download 
           Speed results by Month from NETTFART (Red = 2020, Blue = 2019, 
           Green = 2018, Black = 2017)" ,
           x = "Months", y = "Average Upload speed (Mbs)", colour = 'Legend',
           caption = "Graph by Kwame") + 
  theme(legend.position = c(.95, .95),
        legend.justification = c("right", "top"),
        legend.box.just = "right",
        legend.margin = margin(6, 6, 6, 6),
        plot.title = element_text(hjust = 0.5), 
        plot.subtitle = element_text(hjust = 0.5),
        plot.caption = element_text(hjust = 0.9))+
  scale_x_continuous(breaks = seq(1, 12, 1)) 


LG2 = ggplot(aggmyData_2019, aes(Month, hastighet_opp)) + geom_point()
LG2



#Finding Time range for rush hour
peak1 = myData %>%  
  mutate(clock = format(time, format="%H:%M:%S")) %>%
  filter(clock >= "21:59:00" & clock < "22:02:00") %>%
  dplyr::select(-clock)

